@@ -24,6 +24,7 @@ import os
 import sqlite3
 import time
 import urllib
+import urllib2
 import vmcastmaker
 import xmpp
 from threading import Thread
@@ -88,6 +89,7 @@ class TNApplianceDownloader (Thread):
         """
         try:
             self.logger.info("TNApplianceDownloader: starting to download appliance %s into %s" % (self.url, self.save_path))
+            urllib.urlcleanup()
             urllib.urlretrieve(self.url, self.save_path, self.downloading_callback)
             if self.error:
                 self.finish_callback(ARCHIPEL_DOWNLOAD_ERROR, self.uuid, None)
@@ -173,9 +175,9 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
         if not os.path.exists(self.configuration.get("VMCASTING", "own_vmcast_path")):
             os.makedirs(self.configuration.get("VMCASTING", "own_vmcast_path"))
         self.entity.log.info("TNHypervisorRepoManager: opening vmcasting database file %s" % self.database_path)
-        self.own_vmcastmaker = vmcastmaker.VMCastMaker(self.configuration.get("VMCASTING", "own_vmcast_name").replace("$HOSTAME", self.entity.resource),
+        self.own_vmcastmaker = vmcastmaker.VMCastMaker(self.configuration.get("VMCASTING", "own_vmcast_name").replace("$HOSTNAME", self.entity.resource),
                                                         self.configuration.get("VMCASTING", "own_vmcast_uuid"),
-                                                        self.configuration.get("VMCASTING", "own_vmcast_description").replace("$HOSTAME", self.entity.resource),
+                                                        self.configuration.get("VMCASTING", "own_vmcast_description").replace("$HOSTNAME", self.entity.resource),
                                                         self.configuration.get("VMCASTING", "own_vmcast_lang"),
                                                         self.configuration.get("VMCASTING", "own_vmcast_url"),
                                                         self.configuration.get("VMCASTING", "own_vmcast_path"))
@@ -211,7 +213,8 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
         @type parameters: object
         @param parameters: runtime arguments
         """
-        self.parse_timer.start()
+        if not self.parse_timer.is_alive():
+            self.parse_timer.start()
 
 
     ### Plugin interface
@@ -295,7 +298,6 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
         del self.download_queue[uuid]
         self.entity.change_status(self.old_entity_status)
 
-
     def getFeed(self, data):
         """
         Get the feed.
@@ -304,11 +306,11 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
         @rtype: tupple
         @return: tupple that contains info on the feed
         """
-        feed_content        = xmpp.simplexml.NodeBuilder(data=str(data)).getDom()
-        feed_uuid           = feed_content.getTag("channel").getTag("uuid").getCDATA()
-        feed_description    = feed_content.getTag("channel").getTag("description").getCDATA()
-        feed_name           = feed_content.getTag("channel").getTag("title").getCDATA()
-        items               = feed_content.getTag("channel").getTags("item")
+        feed_content = xmpp.simplexml.NodeBuilder(data=str(data)).getDom()
+        feed_uuid = feed_content.getTag("channel").getTag("uuid").getCDATA()
+        feed_description = feed_content.getTag("channel").getTag("description").getCDATA()
+        feed_name = feed_content.getTag("channel").getTag("title").getCDATA()
+        items = feed_content.getTag("channel").getTags("item")
         return (feed_content, feed_uuid, feed_description, feed_name, items)
 
     def parseRSS(self):
@@ -329,7 +331,8 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
             source_node = xmpp.Node(tag="source", attrs={"name": name, "description": description, "url": url, "uuid": uuid})
             content_nodes = []
             try:
-                f = urllib.urlopen(url)
+                req = urllib2.Request(url, headers={"User-Agent": "Mozilla/5.0 (X11; U; Linux i686) Gecko/20071127 Firefox/2.0.0.11", "Cache-control":  "no-cache"})
+                f = urllib2.urlopen(req)
             except Exception as ex:
                 continue
             try:
@@ -344,14 +347,15 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
             except Exception as ex:
                 self.entity.log.debug("TNHypervisorRepoManager: unable to update source because: " + str(ex))
                 pass
+
             for item in items:
-                name            = str(item.getTag("title").getCDATA())
-                description     = str(item.getTag("description").getCDATA()).replace("\n", "").replace("\t", "")
-                url             = str(item.getTag("enclosure").getAttr("url"))
-                size            = str(item.getTag("enclosure").getAttr("length"))
-                pubdate         = str(item.getTag("pubDate").getCDATA())
-                uuid            = str(item.getTag("uuid").getCDATA())
-                status          = ARCHIPEL_APPLIANCES_NOT_INSTALLED
+                name = str(item.getTag("title").getCDATA())
+                description = str(item.getTag("description").getCDATA()).replace("\n", "").replace("\t", "")
+                url = str(item.getTag("enclosure").getAttr("url"))
+                size = str(item.getTag("enclosure").getAttr("length"))
+                pubdate = str(item.getTag("pubDate").getCDATA())
+                uuid = str(item.getTag("uuid").getCDATA())
+                status = ARCHIPEL_APPLIANCES_NOT_INSTALLED
                 try:
                     tmp_cursor.execute("INSERT INTO vmcastappliances VALUES (?,?,?,?,?,?,?)", (name, description, url, uuid, status, feed_uuid, '/dev/null'))
                     self.database_connection.commit()
@@ -439,6 +443,7 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
             if not url or url == "":
                 raise Exception("IncorrectStanza", "Stanza must have url: %s" % str(iq))
             try:
+                urllib.urlcleanup()
                 f = urllib.urlopen(url)
             except:
                 raise Exception("The given url doesn't exist. Can't register.")
@@ -494,7 +499,7 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
             name, description, url, uuid, status, source, path = self.cursor.fetchone()
             downloader = TNApplianceDownloader(url, self.repository_path, uuid, name, self.entity.log, self.on_download_complete)
             self.download_queue[uuid] = downloader
-            downloader.daemon  = True
+            downloader.daemon = True
             downloader.start()
             self.entity.change_status("Downloading appliance...")
         except Exception as ex:
@@ -594,4 +599,4 @@ class TNHypervisorRepoManager (TNArchipelPlugin):
             self.entity.shout("vmcast", "I've just delete appliance %s as asked by %s" % (uuid, iq.getFrom()))
         except Exception as ex:
             reply = build_error_iq(self, ex, iq, ARCHIPEL_ERROR_CODE_VMCASTS_DELETEAPPLIANCE)
-        return reply
\ No newline at end of file
+        return reply
